==> webkit2gtk_2.48.0.orig.tar.xz: webkitgtk-2.48.0/Source/WebGPU/WGSL/AST/ASTSwitchStatement.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ASTStatement.h"

namespace WGSL::AST {

struct SwitchClause {
    AST::Expression::List selectors;
    AST::CompoundStatement::Ref body;
};

class SwitchStatement final : public Statement {
    WGSL_AST_BUILDER_NODE(SwitchStatement);
public:
    NodeKind kind() const final;
    Expression& value() { return m_value.get(); }
    Attribute::List& valueAttributes() { return m_valueAttributes; }
    Vector<SwitchClause>& clauses() { return m_clauses; }
    SwitchClause& defaultClause() { return m_defaultClause; }

    bool isInsideLoop() const { return m_isInsideLoop; }
    void setIsInsideLoop() { m_isInsideLoop = true;; }

    bool isNestedInsideLoop() const { return m_isNestedInsideLoop; }
    void setIsNestedInsideLoop() { m_isNestedInsideLoop = true; }

private:
    SwitchStatement(SourceSpan span, AST::Expression::Ref&& value, AST::Attribute::List&& valueAttributes, Vector<SwitchClause>&& clauses, SwitchClause&& defaultClause)
        : Statement(span)
        , m_value(WTFMove(value))
        , m_valueAttributes(WTFMove(valueAttributes))
        , m_clauses(WTFMove(clauses))
        , m_defaultClause(WTFMove(defaultClause))
    { }

    bool m_isInsideLoop { false };
    bool m_isNestedInsideLoop { false };
    Expression::Ref m_value;
    Attribute::List m_valueAttributes;
    Vector<SwitchClause> m_clauses;
    SwitchClause m_defaultClause;
};

} // namespace WGSL::AST

SPECIALIZE_TYPE_TRAITS_WGSL_AST(SwitchStatement)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebGPU/WGSL/AST/ASTSwitchStatement.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ASTStatement.h"

namespace WGSL::AST {

struct SwitchClause {
    AST::Expression::List selectors;
    AST::CompoundStatement::Ref body;
};

class SwitchStatement final : public Statement {
    WGSL_AST_BUILDER_NODE(SwitchStatement);
public:
    NodeKind kind() const final;
    Expression& value() { return m_value.get(); }
    Attribute::List& valueAttributes() { return m_valueAttributes; }
    Vector<SwitchClause>& clauses() { return m_clauses; }
    SwitchClause& defaultClause() { return m_defaultClause; }

    bool isInsideLoop() const { return m_isInsideLoop; }
    void setIsInsideLoop() { m_isInsideLoop = true;; }

    bool isNestedInsideLoop() const { return m_isNestedInsideLoop; }
    void setIsNestedInsideLoop() { m_isNestedInsideLoop = true; }

private:
    SwitchStatement(SourceSpan span, AST::Expression::Ref&& value, AST::Attribute::List&& valueAttributes, Vector<SwitchClause>&& clauses, SwitchClause&& defaultClause)
        : Statement(span)
        , m_value(WTF::move(value))
        , m_valueAttributes(WTF::move(valueAttributes))
        , m_clauses(WTF::move(clauses))
        , m_defaultClause(WTF::move(defaultClause))
    { }

    bool m_isInsideLoop { false };
    bool m_isNestedInsideLoop { false };
    Expression::Ref m_value;
    Attribute::List m_valueAttributes;
    Vector<SwitchClause> m_clauses;
    SwitchClause m_defaultClause;
};

} // namespace WGSL::AST

SPECIALIZE_TYPE_TRAITS_WGSL_AST(SwitchStatement)
